ardt.datasets.ascertain.AscertainDataset
========================================

.. currentmodule:: ardt.datasets.ascertain

.. autoclass:: AscertainDataset

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~AscertainDataset.__init__
      ~AscertainDataset.get_media_name_by_movie_id
      ~AscertainDataset.get_signal_metadata
      ~AscertainDataset.get_trial_splits
      ~AscertainDataset.get_working_dir
      ~AscertainDataset.get_working_path
      ~AscertainDataset.load_trials
      ~AscertainDataset.preload
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~AscertainDataset.expected_media_responses
      ~AscertainDataset.media_file_offset
      ~AscertainDataset.media_ids
      ~AscertainDataset.participant_ids
      ~AscertainDataset.participant_offset
      ~AscertainDataset.signal_preprocessors
      ~AscertainDataset.signals
      ~AscertainDataset.trials
   
   